@@ -10,7 +10,7 @@
 
 struct db_main db;
 
-void db_init()
+void db_init(void)
 {
 	db.head = db.tail = NULL;
 	db.total_count = 0;
@@ -58,7 +58,7 @@ int db_delete(struct db_message *msg)
 	return 0;
 }
 
-int db_fix()
+int db_fix(void)
 {
 	int size;
 	struct db_message *entry;
