@@ -29,7 +29,7 @@ struct db_message {
 	int flags;			/* MSG_* flags defined above */
 	long raw_offset, raw_size;	/* Raw, with the "From " line */
 	long data_offset, data_size;	/* Just the message itself */
-	md5_uint32 hash[4];		/* MD5 hash, to be used for UIDL */
+	unsigned char hash[16];		/* MD5 hash, to be used for UIDL */
 };
 
 struct db_main {
@@ -45,9 +45,9 @@ struct db_main {
 
 extern struct db_main db;
 
-extern void db_init();
+extern void db_init(void);
 extern int db_add(struct db_message *msg);
 extern int db_delete(struct db_message *msg);
-extern int db_fix();
+extern int db_fix(void);
 
 #endif
