@@ -12,14 +12,15 @@
 extern int sleep_select(int sec, int usec);
 
 /*
- * Obtains an exclusive lock, restarting on possible EBUSY errors.
+ * Obtain or remove a lock.
  */
-extern int flock_loop(int fd);
+extern int lock_fd(int fd, int shared);
+extern int unlock_fd(int fd);
 
 /*
  * Attempts to write all the supplied data. Returns the number of bytes
  * written. Any value that differs from the requested count means that
- * an error has occured; if the value is -1, errno is set appropriately.
+ * an error has occurred; if the value is -1, errno is set appropriately.
  */
 extern int write_loop(int fd, char *buffer, int count);
 
